@@ -10,7 +10,7 @@ use Getopt::Long qw( GetOptions );
 use Pod::Usage qw( pod2usage );
 
 # ABSTRACT: Convert PATH type environment variables to spaceless versions
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 
 sub _running_shell
@@ -79,7 +79,7 @@ sub main
 
   my $to_long = $^O eq 'cygwin' ? sub { Cygwin::win_to_posix_path(Win32::GetLongPathName(Cygwin::posix_to_win_path($_))) } : sub { Win32::GetLongPathName($_[0]) };
 
-  my $mutator = $expand ? sub { map { $to_long->($_) } @_ } : sub { win32_space_be_gone(@_) };
+  my $mutator = $expand ? sub { map { $to_long->($_) } @_ } : sub { win32_space_be_gone(grep { -e $_ } @_) };
 
   foreach my $var (@ARGV)
   {
@@ -128,7 +128,7 @@ App::spaceless - Convert PATH type environment variables to spaceless versions
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 DESCRIPTION
 
